@@ -17,7 +17,7 @@ from typing import (
     Union,
 )
 from xml.etree import ElementTree as ET
-from xml.sax.saxutils import escape, unescape
+from xml.sax.saxutils import escape
 
 import defusedxml.ElementTree as DET
 import voluptuous as vol
@@ -32,7 +32,7 @@ from async_upnp_client.const import (
 )
 
 _LOGGER = logging.getLogger(__name__)
-_LOGGER_TRAFFIC = logging.getLogger("async_upnp_client.traffic")
+_LOGGER_TRAFFIC_UPNP = logging.getLogger("async_upnp_client.traffic.upnp")
 
 
 EventCallbackType = Callable[["UpnpService", Sequence["UpnpStateVariable"]], None]
@@ -65,7 +65,7 @@ class UpnpRequester:
         :return status code, headers, body
         """
         # pylint: disable=too-many-arguments
-        _LOGGER_TRAFFIC.debug(
+        _LOGGER_TRAFFIC_UPNP.debug(
             "Sending request:\n%s %s\n%s\n%s\n",
             method,
             url,
@@ -83,7 +83,7 @@ class UpnpRequester:
         log_response_body = (
             response_body if body_type == "text" else "async_upnp_client: OMITTING BODY"
         )
-        _LOGGER_TRAFFIC.debug(
+        _LOGGER_TRAFFIC_UPNP.debug(
             "Got response:\n%s\n%s\n\n%s",
             response_status,
             "\n".join([key + ": " + value for key, value in response_headers.items()]),
@@ -135,8 +135,11 @@ class UpnpDevice:
         requester: UpnpRequester,
         device_info: DeviceInfo,
         services: Sequence["UpnpService"],
+        boot_id: Optional[str] = None,
+        config_id: Optional[str] = None,
     ) -> None:
         """Initialize."""
+        # pylint: disable=too-many-arguments
         self.requester = requester
         self._device_info = device_info
         self.services = {service.service_type: service for service in services}
@@ -145,6 +148,12 @@ class UpnpDevice:
         for service in services:
             service.device = self
 
+        self.boot_id: Optional[str] = boot_id
+        self.config_id: Optional[str] = config_id
+
+        # Just initialized, mark available.
+        self.available = True
+
     @property
     def name(self) -> str:
         """Get the name of this device."""
@@ -208,6 +217,13 @@ class UpnpDevice:
         """Get service by service_type."""
         return self.services[service_type]
 
+    def service_id(self, service_id: str) -> Optional["UpnpService"]:
+        """Get service by service_id."""
+        for service in self.services.values():
+            if service.service_id == service_id:
+                return service
+        return None
+
     async def async_ping(self) -> None:
         """Ping the device."""
         await self.requester.async_http_request("GET", self.device_url)
@@ -257,9 +273,6 @@ class UpnpService:
     @device.setter
     def device(self, device: UpnpDevice) -> None:
         """Set parent UpnpDevice."""
-        if self._device:
-            raise UpnpError("UpnpService already bound to UpnpDevice")
-
         self._device = device
 
     @property
@@ -492,9 +505,6 @@ class UpnpAction:
     @service.setter
     def service(self, service: UpnpService) -> None:
         """Set parent UpnpService."""
-        if self._service:
-            raise UpnpError("UpnpAction already bound to UpnpService")
-
         self._service = service
 
     def __str__(self) -> str:
@@ -623,7 +633,7 @@ class UpnpAction:
         try:
             return self._parse_response_args(service_type, xml)
         except AttributeError:
-            _LOGGER.debug("Error during unescape of: %s", response_body)
+            _LOGGER.debug("Could not parse response: %s", response_body)
             raise
 
     def _parse_response_args(
@@ -651,11 +661,7 @@ class UpnpAction:
                 )
 
             arg.raw_upnp_value = arg_xml.text
-            try:
-                arg.upnp_value = unescape(arg_xml.text or "")
-            except AttributeError:
-                _LOGGER.debug("Error during unescape of: %s", arg_xml.text)
-                raise
+            arg.upnp_value = arg_xml.text or ""
             args[name] = arg.value
 
         return args
@@ -691,9 +697,6 @@ class UpnpStateVariable(Generic[T]):
     @service.setter
     def service(self, service: UpnpService) -> None:
         """Set parent UpnpService."""
-        if self._service:
-            raise UpnpError("UpnpStateVariable already bound to UpnpService")
-
         self._service = service
 
     @property
