@@ -5,6 +5,7 @@ import asyncio
 import logging
 from datetime import datetime, timedelta
 from enum import Enum
+from mimetypes import guess_type
 from typing import Any, List, Mapping, MutableMapping, Optional, Sequence
 from urllib.parse import quote_plus, urlparse, urlunparse
 from xml.sax.handler import ContentHandler, ErrorHandler
@@ -13,15 +14,21 @@ from defusedxml.sax import parseString
 from didl_lite import didl_lite
 
 from async_upnp_client import UpnpError, UpnpService, UpnpStateVariable
+from async_upnp_client.const import MIME_TO_UPNP_CLASS_MAPPING
 from async_upnp_client.profiles.profile import UpnpProfileDevice
 from async_upnp_client.utils import absolute_url, str_to_time, time_to_str
 
 _LOGGER = logging.getLogger(__name__)
 
 
-DeviceState = Enum(
-    "DeviceState", "ON PLAYING PAUSED IDLE"
-)  # pylint: disable=invalid-name
+DeviceState = Enum("DeviceState", "ON PLAYING PAUSED IDLE")
+
+
+TransportState = Enum(
+    "TransportState",
+    "STOPPED PLAYING TRANSITIONING PAUSED_PLAYBACK PAUSED_RECORDING RECORDING NO_MEDIA_PRESENT "
+    "VENDOR_DEFINED",
+)
 
 
 class DlnaOrgOp(Enum):
@@ -97,18 +104,25 @@ class DlnaDmrEventContentHandler(ContentHandler):
             self._current_instance = attrs.get("val", "0")
         else:
             current_instance = self._current_instance or "0"  # safety
+
             if current_instance not in self.changes:
                 self.changes[current_instance] = {}
 
-            # if channel is given, we're only interested in the Master channel
+            # If channel is given, we're only interested in the Master channel.
             if attrs.get("channel") not in (None, "Master"):
                 return
 
+            # Strip namespace prefix.
+            if ":" in name:
+                index = name.find(":") + 1
+                name = name[index:]
+
             self.changes[current_instance][name] = attrs.get("val")
 
     def endElement(self, name: str) -> None:
         """Handle endElement."""
-        self._current_instance = None
+        if name == "InstanceID":
+            self._current_instance = None
 
 
 class DlnaDmrEventErrorHandler(ErrorHandler):
@@ -256,7 +270,12 @@ class DmrDevice(UpnpProfileDevice):
 
     @property
     def state(self) -> DeviceState:
-        """Get current state."""
+        """
+        Get current state.
+
+        This property is deprecated and will be removed in a future version!
+        Please use `transport_state` instead.
+        """
         state_var = self._state_variable("AVT", "TransportState")
         if not state_var:
             return DeviceState.ON
@@ -264,11 +283,26 @@ class DmrDevice(UpnpProfileDevice):
         state_value = (state_var.value or "").strip().lower()
         if state_value == "playing":
             return DeviceState.PLAYING
-        if state_value == "paused":
+        if state_value in ("paused", "paused_playback"):
             return DeviceState.PAUSED
 
         return DeviceState.IDLE
 
+    @property
+    def transport_state(self) -> Optional[TransportState]:
+        """Get transport state."""
+        state_var = self._state_variable("AVT", "TransportState")
+        if not state_var:
+            return None
+
+        state_value = (state_var.value or "").strip().upper()
+        for member in TransportState:
+            if member.name == state_value:
+                return member
+
+        # Unknown state; return VENDOR_DEFINED.
+        return TransportState.VENDOR_DEFINED
+
     @property
     def _has_current_transport_actions(self) -> bool:
         state_var = self._state_variable("AVT", "CurrentTransportActions")
@@ -607,13 +641,7 @@ class DmrDevice(UpnpProfileDevice):
         return self._action("AVT", "SetAVTransportURI") is not None
 
     async def async_set_transport_uri(
-        self,
-        media_url: str,
-        media_title: str,
-        mime_type: str,
-        upnp_class: str,
-        override_mime_type: Optional[str] = None,
-        override_dlna_features: Optional[str] = None,
+        self, media_url: str, media_title: str, meta_data: Optional[str] = None
     ) -> None:
         """Play a piece of media."""
         # pylint: disable=too-many-arguments
@@ -632,14 +660,8 @@ class DmrDevice(UpnpProfileDevice):
         )
 
         # queue media
-        meta_data = await self._construct_play_media_metadata(
-            media_url,
-            media_title,
-            mime_type,
-            upnp_class,
-            override_mime_type=override_mime_type,
-            override_dlna_features=override_dlna_features,
-        )
+        if not meta_data:
+            meta_data = await self.construct_play_media_metadata(media_url, media_title)
         action = self._action("AVT", "SetAVTransportURI")
         if not action:
             raise UpnpError("Missing action AVT/SetAVTransportURI")
@@ -681,13 +703,14 @@ class DmrDevice(UpnpProfileDevice):
 
         return None
 
-    async def _construct_play_media_metadata(
+    async def construct_play_media_metadata(
         self,
         media_url: str,
         media_title: str,
-        mime_type: str,
-        upnp_class: str,
+        default_mime_type: Optional[str] = None,
+        default_upnp_class: Optional[str] = None,
         override_mime_type: Optional[str] = None,
+        override_upnp_class: Optional[str] = None,
         override_dlna_features: Optional[str] = None,
     ) -> str:
         """
@@ -697,56 +720,71 @@ class DmrDevice(UpnpProfileDevice):
 
         :arg media_url URL to media
         :arg media_title
-        :arg mime_type Suggested mime type, will be overridden by source if possible
-        :arg upnp_class UPnP class
-        :arg override_mime_type Enfore mime_type, even if source reports a different mime_type
+        :arg default_mime_type Suggested mime type, will be overridden by source if possible
+        :arg default_upnp_class Suggested UPnP class, will be used as fallback for autodetection
+        :arg override_mime_type Enforce mime_type, even if source reports a different mime_type
+        :arg override_upnp_class Enforce upnp_class, even if autodetection finds something usable
         :arg override_dlna_features Enforce DLNA features, even if source reports different features
         :return String containing metadata
         """
-        # pylint: disable=too-many-arguments, too-many-locals
-        media_info = {
-            "mime_type": mime_type,
-            "dlna_features": "*",
-        }
+        # pylint: disable=too-many-arguments, too-many-locals, too-many-branches
+        mime_type = override_mime_type or ""
+        upnp_class = override_upnp_class or ""
+        dlna_features = override_dlna_features or "*"
 
-        # do a HEAD/GET, to retrieve content-type/mime-type
-        try:
-            headers = await self._fetch_headers(
-                media_url, {"GetContentFeatures.dlna.org": "1"}
-            )
-            if headers:
-                if "Content-Type" in headers:
-                    media_info["mime_type"] = headers["Content-Type"]
-
-                if "ContentFeatures.dlna.org" in headers:
-                    media_info["dlna_features"] = headers["contentFeatures.dlna.org"]
-        except Exception:  # pylint: disable=broad-except
-            pass
-
-        # use CM/GetProtocolInfo to improve on dlna_features
-        if self.has_get_protocol_info:
-            protocol_info_entries = (
-                await self._async_get_sink_protocol_info_for_mime_type(
-                    media_info["mime_type"]
+        if None in (override_mime_type, override_dlna_features):
+            # do a HEAD/GET, to retrieve content-type/mime-type
+            try:
+                headers = await self._fetch_headers(
+                    media_url, {"GetContentFeatures.dlna.org": "1"}
                 )
-            )
-            for entry in protocol_info_entries:
-                if entry[3] == "*":
-                    # device accepts anything, send this
-                    media_info["dlna_features"] = "*"
+                if headers:
+                    if not override_mime_type and "Content-Type" in headers:
+                        mime_type = headers["Content-Type"]
+                    if (
+                        not override_dlna_features
+                        and "ContentFeatures.dlna.org" in headers
+                    ):
+                        dlna_features = headers["contentFeatures.dlna.org"]
+            except Exception:  # pylint: disable=broad-except
+                pass
 
-        # allow overriding of mime_type/dlna_features
-        if override_mime_type:
-            media_info["mime_type"] = override_mime_type
-        if override_dlna_features:
-            media_info["dlna_features"] = override_dlna_features
+            if not mime_type:
+                _type = guess_type(media_url.split("?")[0])
+                mime_type = _type[0] or ""
+                if not mime_type:
+                    mime_type = default_mime_type or "application/octet-stream"
+
+            # use CM/GetProtocolInfo to improve on dlna_features
+            if (
+                not override_dlna_features
+                and dlna_features != "*"
+                and self.has_get_protocol_info
+            ):
+                protocol_info_entries = (
+                    await self._async_get_sink_protocol_info_for_mime_type(mime_type)
+                )
+                for entry in protocol_info_entries:
+                    if entry[3] == "*":
+                        # device accepts anything, send this
+                        dlna_features = "*"
+
+        # Try to derive a basic upnp_class from mime_type
+        if not override_upnp_class:
+            mime_type = mime_type.lower()
+            for _mime, _class in MIME_TO_UPNP_CLASS_MAPPING.items():
+                if mime_type.startswith(_mime):
+                    upnp_class = _class
+                    break
+            else:
+                upnp_class = default_upnp_class or "object.item"
 
         # build DIDL-Lite item + resource
         didl_item_type = didl_lite.type_by_upnp_class(upnp_class)
         if not didl_item_type:
             raise UpnpError("Unknown DIDL-lite type")
 
-        protocol_info = "http-get:*:{mime_type}:{dlna_features}".format(**media_info)
+        protocol_info = f"http-get:*:{mime_type}:{dlna_features}"
         resource = didl_lite.Resource(uri=media_url, protocol_info=protocol_info)
         item = didl_item_type(
             id="0",
